from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Driver_Motor = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'A4950E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A4950E'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8-1EP_3.9x4.9mm_P1.27mm_EP2.41x3.3mm'], 'footprint':'Package_SO:SOIC-8-1EP_3.9x4.9mm_P1.27mm_EP2.41x3.3mm', 'keywords':'full-bridge h-bridge', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A4950-Datasheet.ashx', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nA4950E\n\nfull-bridge h-bridge', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='LSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='PAD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A4952_LY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A4952_LY'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10-1EP_3x3mm_P0.5mm_EP1.73x1.98mm'], 'footprint':'Package_SO:MSOP-10-1EP_3x3mm_P0.5mm_EP1.73x1.98mm', 'keywords':'Full-bridge h-bridge', 'description':'', 'datasheet':'www.allegromicro.com/~/media/Files/Datasheets/A4952-3-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nA4952_LY\n\nFull-bridge h-bridge', 'pins':[
            Pin(num='1',name='~{FLTn}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RTRY',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='OUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='LSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OUT2',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A4954', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A4954'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16-1EP_4.4x5mm_P0.65mm_EP3x3mm'], 'footprint':'Package_SO:TSSOP-16-1EP_4.4x5mm_P0.65mm_EP3x3mm', 'keywords':'Fullbridge, Stepper Driver', 'description':'', 'datasheet':'https://www.allegromicro.com/-/media/Files/Datasheets/A4954-Datasheet.ashx', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nA4954\n\nFullbridge, Stepper Driver', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='LSS12',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='OUT2',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='OUT3',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='LSS34',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OUT4',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='VBB',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VREF34',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VREF12',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VBB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AMT49413', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AMT49413'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.15x5.15mm_ThermalVias', 'keywords':'BLDC 3-Phase', 'description':'', 'datasheet':'https://www.allegromicro.com/-/media/Files/Datasheets/AMT49413-Datasheet.ashx', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nAMT49413\n\nBLDC 3-Phase', 'pins':[
            Pin(num='1',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='H1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='H2',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='H3',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='RC',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='RDEAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='CSOUT',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='CSN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CSP',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VDSTH',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VDRAIN',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='SC',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='GHC',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='CC',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='SB',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='GHB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='V5DB',func=pin_types.PWROUT,unit=1),
            Pin(num='30',name='CB',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='SA',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='GHA',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='CA',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='GLC',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='GLB',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='GLA',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='38',name='LSS',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='ESF',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V5',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='VREG',func=pin_types.PWROUT,unit=1),
            Pin(num='41',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='CP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='CP2',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DIRO',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='COAST',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='FF2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='FF1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='TACHO',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='BRAKE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DIR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8308', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8308'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RHA0040E_VQFN-40-1EP_6x6mm_P0.5mm_EP3.52x2.62mm'], 'footprint':'Package_DFN_QFN:Texas_RHA0040E_VQFN-40-1EP_6x6mm_P0.5mm_EP3.52x2.62mm', 'keywords':'bldc mosfet-driver hall-sensor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8308.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8308\n\nbldc mosfet-driver hall-sensor', 'pins':[
            Pin(num='1',name='UHP',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='FGINP',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCS',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SMODE',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDATAI',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDATAO',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='FGOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{FAULTn}',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='~{LOCKn}',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='UHN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='BRAKE',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VREG',func=pin_types.PWROUT,unit=1),
            Pin(num='25',name='VINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='CP2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VHP',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='CP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='ISEN',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='UHSG',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='U',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='ULSG',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='VHSG',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='V',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='VLSG',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='WHSG',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='W',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VHN',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='WLSG',func=pin_types.OUTPUT,unit=1),
            Pin(num='41',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='WHP',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='WHN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VSW',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='FGFB',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='FGINN_TACH',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8412', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8412'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-44-1EP_6.1x14mm_P0.635mm_EP5.2x14mm_Mask4.31x8.26mm_ThermalVias'], 'footprint':'Package_SO:HTSSOP-44-1EP_6.1x14mm_P0.635mm_EP5.2x14mm_Mask4.31x8.26mm_ThermalVias', 'keywords':'Dual Full-Bridge PWM Motor Driver', 'description':'', 'datasheet':'https://www.ti.com/lit/gpn/DRV8412', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8412\n\nDual Full-Bridge PWM Motor Driver', 'pins':[
            Pin(num='1',name='GVDD_C',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='M3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VREG',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='OC_ADJ',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PWM_B',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{RESET_AB}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='PWM_A',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='19',name='NC/GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='NC/GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='~{OTW}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='22',name='GVDD_B',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='GVDD_A',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='BST_A',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='NC/GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PVDD_A',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='PVDD_A',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='OUT_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='GND_A',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC/GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='GND_B',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='OUT_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='PVDD_B',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='BST_B',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='BST_C',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PVDD_C',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='OUT_C',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='GND_C',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='GND_D',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='OUT_D',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='NC/GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='40',name='PVDD_D',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='PVDD_D',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='NC/GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='BST_D',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='GVDD_D',func=pin_types.PWRIN,unit=1),
            Pin(num='45',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PWM_D',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{RESET_CD}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PWM_C',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='M2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8432', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8432'}), 'ref_prefix':'U', 'fplist':['Package_SO:HSOP-36-1EP_11.0x15.9mm_P0.65mm_SlugUp'], 'footprint':'Package_SO:HSOP-36-1EP_11.0x15.9mm_P0.65mm_SlugUp', 'keywords':'Dual Full-Bridge PWM Motor Driver', 'description':'', 'datasheet':'https://www.ti.com/lit/gpn/DRV8412', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8432\n\nDual Full-Bridge PWM Motor Driver', 'pins':[
            Pin(num='1',name='GVDD_B',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VREG',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='M3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PWM_C',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{RESET_CD}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PWM_D',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GVDD_C',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GVDD_D',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{OTW}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='BST_D',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='PVDD_D',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='OUT_D',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='GND_D',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='GND_C',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='OUT_C',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='PVDD_C',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='BST_C',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='BST_B',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='PVDD_B',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='30',name='OUT_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='GND_B',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='GND_A',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='OUT_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='34',name='PVDD_A',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='BST_A',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='GVDD_A',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PWM_A',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{RESET_AB}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='PWM_B',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OC_ADJ',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='AGND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8461SPWP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8461SPWP'}), 'ref_prefix':'U', 'fplist':['Package_SO:Texas_PWP0020A'], 'footprint':'Package_SO:Texas_PWP0020A', 'keywords':'texas ti microstep driver silent STEP DIR', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/drv8461.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8461SPWP\n\ntexas ti microstep driver silent STEP DIR', 'pins':[
            Pin(num='1',name='VCP',func=pin_types.INPUT),
            Pin(num='10',name='BOUT1',func=pin_types.OUTPUT),
            Pin(num='16',name='~{FAULT}',func=pin_types.OPENCOLL),
            Pin(num='17',name='VREF',func=pin_types.INPUT),
            Pin(num='18',name='~{SCS}',func=pin_types.INPUT),
            Pin(num='19',name='VCC',func=pin_types.PWRIN),
            Pin(num='20',name='SDO',func=pin_types.OUTPUT),
            Pin(num='21',name='SDI',func=pin_types.INPUT),
            Pin(num='22',name='SCLK',func=pin_types.INPUT),
            Pin(num='23',name='STEP',func=pin_types.INPUT),
            Pin(num='24',name='DIR',func=pin_types.INPUT),
            Pin(num='25',name='ENABLE',func=pin_types.INPUT),
            Pin(num='26',name='~{SLEEP}',func=pin_types.INPUT),
            Pin(num='27',name='CPL',func=pin_types.INPUT),
            Pin(num='28',name='CPH',func=pin_types.INPUT),
            Pin(num='3',name='GND',func=pin_types.PWRIN),
            Pin(num='4',name='AOUT1',func=pin_types.OUTPUT),
            Pin(num='6',name='AOUT2',func=pin_types.OUTPUT),
            Pin(num='8',name='BOUT2',func=pin_types.OUTPUT),
            Pin(num='11',name='BOUT1',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='VM',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='DVDD',func=pin_types.PWROUT,unit=1),
            Pin(num='2',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AOUT1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='AOUT2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='BOUT2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8662', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8662'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RGP0020D_VQFN-20-1EP_4x4mm_P0.5mm_EP2.7x2.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Texas_RGP0020D_VQFN-20-1EP_4x4mm_P0.5mm_EP2.7x2.7mm_ThermalVias', 'keywords':'piezo driver boost', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8662.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8662\n\npiezo driver boost', 'pins':[
            Pin(num='1',name='VPUMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VBST',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='VBST',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OUT-',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='REXT',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GAIN0',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='GAIN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='FB',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='SW',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SW',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8711', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8711'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/slvsc40f/slvsc40f.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8711\n\nStepper driver', 'pins':[
            Pin(num='1',name='CP1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='STEP/AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DIR/AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='BIN1',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='BIN2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDATI',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCS',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SDATO',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='FAULTn',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='STALLn/BEMFVn',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CP2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BEMF',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='BOUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='B2HS',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='B2LS',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='BISENN',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='BISENP',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='B1LS',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='B1HS',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='BOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCP',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AOUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='A2HS',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='A2LS',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='AISENN',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='AISENP',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A1LS',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='A1HS',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='AOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='38',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='V5',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='VINT',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SLEEPn',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='RESET',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8800PWP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8800PWP'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-16-1EP_4.4x5mm_P0.65mm_EP3.4x5mm_Mask3x3mm_ThermalVias'], 'footprint':'Package_SO:HTSSOP-16-1EP_4.4x5mm_P0.65mm_EP3.4x5mm_Mask3x3mm_ThermalVias', 'keywords':'H-Bridge Motor Driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8801.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8800PWP\n\nH-Bridge Motor Driver', 'pins':[
            Pin(num='1',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='OUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='CP1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='CP2',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VCP',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VREG',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='GND(PPAD)',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='PHASE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='SENSE',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='VBB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8800RTY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8800RTY'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RTY_WQFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Texas_RTY_WQFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm_ThermalVias', 'keywords':'H-Bridge Motor Driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8801.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8800RTY\n\nH-Bridge Motor Driver', 'pins':[
            Pin(num='1',name='PHASE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CP1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='CP2',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCP',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VREG',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND(PPAD)',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='OUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='SENSE',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OUT-',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8801PWP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8801PWP'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-16-1EP_4.4x5mm_P0.65mm_EP3.4x5mm_Mask3x3mm_ThermalVias'], 'footprint':'Package_SO:HTSSOP-16-1EP_4.4x5mm_P0.65mm_EP3.4x5mm_Mask3x3mm_ThermalVias', 'keywords':'H-Bridge Motor Driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8801.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8801PWP\n\nH-Bridge Motor Driver', 'pins':[
            Pin(num='1',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='OUT-',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='CP1',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='CP2',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VCP',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VPROPI',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='MODE2',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND(PPAD)',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='MODE1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='PHASE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='SENSE',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='VBB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8801RTY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8801RTY'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RTY_WQFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Texas_RTY_WQFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm_ThermalVias', 'keywords':'H-Bridge Motor Driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8801.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8801RTY\n\nH-Bridge Motor Driver', 'pins':[
            Pin(num='1',name='PHASE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='CP1',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='CP2',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCP',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VPROPI',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='MODE1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND(PPAD)',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='MODE2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='OUT+',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='SENSE',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OUT-',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8833PW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8833PW'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'H-bridge motor driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8833.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8833PW\n\nH-bridge motor driver', 'pins':[
            Pin(num='1',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='BIN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VCP',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VINT',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AOUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='AISEN',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AOUT2',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='BOUT2',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='BISEN',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='BOUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='BIN1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8833PWP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8833PWP'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-16-1EP_4.4x5mm_P0.65mm_EP3.4x5mm_Mask2.46x2.31mm_ThermalVias'], 'footprint':'Package_SO:HTSSOP-16-1EP_4.4x5mm_P0.65mm_EP3.4x5mm_Mask2.46x2.31mm_ThermalVias', 'keywords':'H-bridge motor driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8833.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8833PWP\n\nH-bridge motor driver', 'pins':[
            Pin(num='1',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='BIN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VCP',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VINT',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='AOUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='AISEN',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='AOUT2',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='BOUT2',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='BISEN',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='BOUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='BIN1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8833RTY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8833RTY'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Texas_RTY_WQFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Texas_RTY_WQFN-16-1EP_4x4mm_P0.65mm_EP2.1x2.1mm_ThermalVias', 'keywords':'H-bridge motor driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8833.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8833RTY\n\nH-bridge motor driver', 'pins':[
            Pin(num='1',name='AISEN',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VINT',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AOUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='AOUT2',func=pin_types.PWROUT,unit=1),
            Pin(num='3',name='BOUT2',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='BISEN',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='BOUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='BIN1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='BIN2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8837C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8837C'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-8-1EP_2x2mm_P0.5mm_EP0.9x1.6mm'], 'footprint':'Package_SON:WSON-8-1EP_2x2mm_P0.5mm_EP0.9x1.6mm', 'keywords':'half bridge driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8837c.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8837C\n\nhalf bridge driver', 'pins':[
            Pin(num='1',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8838', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8838'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-8-1EP_2x2mm_P0.5mm_EP0.9x1.6mm'], 'footprint':'Package_SON:WSON-8-1EP_2x2mm_P0.5mm_EP0.9x1.6mm', 'keywords':'half bridge driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8837.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8838\n\nhalf bridge driver', 'pins':[
            Pin(num='1',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='PH',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8847PWP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8847PWP'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-16-1EP_4.4x5mm_P0.65mm_EP3.4x5mm_Mask2.46x2.31mm_ThermalVias'], 'footprint':'Package_SO:HTSSOP-16-1EP_4.4x5mm_P0.65mm_EP3.4x5mm_Mask2.46x2.31mm_ThermalVias', 'keywords':'Dual H-Bridge motor driver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/drv8847.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8847PWP\n\nDual H-Bridge motor driver', 'pins':[
            Pin(num='1',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='TRQ',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='PPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='ISEN12',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='ISEN34',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='IN3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8847PWR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8847PWR'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'Dual H-Bridge motor driver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/drv8847.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8847PWR\n\nDual H-Bridge motor driver', 'pins':[
            Pin(num='1',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='TRQ',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='ISEN12',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='ISEN34',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='IN3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8847RTE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8847RTE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.7x1.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-16-1EP_3x3mm_P0.5mm_EP1.7x1.7mm_ThermalVias', 'keywords':'Dual H-Bridge motor driver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/drv8847.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8847RTE\n\nDual H-Bridge motor driver', 'pins':[
            Pin(num='1',name='ISEN12',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='PPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='ISEN34',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='7',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='TRQ',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8847SPWR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8847SPWR'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16_4.4x5mm_P0.65mm', 'keywords':'Dual H-Bridge motor driver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/drv8847.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8847SPWR\n\nDual H-Bridge motor driver', 'pins':[
            Pin(num='1',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='ISEN12',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='ISEN34',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='IN3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8848', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8848'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-16-1EP_4.4x5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-16-1EP_4.4x5mm_P0.65mm', 'keywords':'Dual H-Bridge motor driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8848.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8848\n\nDual H-Bridge motor driver', 'pins':[
            Pin(num='1',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='BIN2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VINT',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='AOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='AISEN',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='AOUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='BOUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='BISEN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='BOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='BIN1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8870DDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8870DDA'}), 'ref_prefix':'U', 'fplist':['Package_SO:Texas_HTSOP-8-1EP_3.9x4.9mm_P1.27mm_EP2.95x4.9mm_Mask2.4x3.1mm_ThermalVias'], 'footprint':'Package_SO:Texas_HTSOP-8-1EP_3.9x4.9mm_P1.27mm_EP2.95x4.9mm_Mask2.4x3.1mm_ThermalVias', 'keywords':'H-bridge driver motor current limit', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8870.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8870DDA\n\nH-bridge driver motor current limit', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='ISEN',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8871DDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8871DDA'}), 'ref_prefix':'U', 'fplist':['Package_SO:Texas_HTSOP-8-1EP_3.9x4.9mm_P1.27mm_EP2.95x4.9mm_Mask2.4x3.1mm_ThermalVias'], 'footprint':'Package_SO:Texas_HTSOP-8-1EP_3.9x4.9mm_P1.27mm_EP2.95x4.9mm_Mask2.4x3.1mm_ThermalVias', 'keywords':'H-bridge driver motor current limit', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8871.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8871DDA\n\nH-bridge driver motor current limit', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ILIM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8872DDA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8872DDA'}), 'ref_prefix':'U', 'fplist':['Package_SO:Texas_HTSOP-8-1EP_3.9x4.9mm_P1.27mm_EP2.95x4.9mm_Mask2.4x3.1mm_ThermalVias'], 'footprint':'Package_SO:Texas_HTSOP-8-1EP_3.9x4.9mm_P1.27mm_EP2.95x4.9mm_Mask2.4x3.1mm_ThermalVias', 'keywords':'H-bridge driver motor current limit', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8872.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8872DDA\n\nH-bridge driver motor current limit', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='nFAULT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='ISEN',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L293', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L293'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_DIP:DIP-16_W7.62mm', 'keywords':'Half-H Driver Motor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/l293.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nL293\n\nHalf-H Driver Motor', 'pins':[
            Pin(num='1',name='EN1,2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3A',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='3Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='4Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='4A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='1Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='2Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='EN3,4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L293E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L293E'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-20_W7.62mm'], 'footprint':'Package_DIP:DIP-20_W7.62mm', 'keywords':'Half-H Driver Motor Sense', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/l293e.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nL293E\n\nHalf-H Driver Motor Sense', 'pins':[
            Pin(num='1',name='EN12',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='EN34',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='SENSE3',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='SENSE4',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SENSE1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='SENSE2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='IN2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L297', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L297'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Stepper Motor Controller', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/cd00000063.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nL297\n\nStepper Motor Controller', 'pins':[
            Pin(num='11',name='CONTROL',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='SENS2',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SENS1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='Vref',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='OSC',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='CW',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='HALF',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='SYNC',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='HOME',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='INH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='B',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='C',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='INH2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='D',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L298HN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L298HN'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead5.84mm_TabDown'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead5.84mm_TabDown', 'keywords':'H-bridge motor driver', 'description':'', 'datasheet':'http://www.st.com/st-web-ui/static/active/en/resource/technical/document/datasheet/CD00000240.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nL298HN\n\nH-bridge motor driver', 'pins':[
            Pin(num='1',name='SENSE_A',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='EnB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SENSE_B',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='EnA',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Vss',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L298P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L298P'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'H-bridge motor driver', 'description':'', 'datasheet':'http://www.st.com/st-web-ui/static/active/en/resource/technical/document/datasheet/CD00000240.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nL298P\n\nH-bridge motor driver', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='Vss',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='EnB',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='SENSE_B',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SENSE_A',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='EnA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LMD18200', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMD18200'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'keywords':'H-Bridge DC stepper servo motor driver Motion Control Applications', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmd18200.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nLMD18200\n\nH-Bridge DC stepper servo motor driver Motion Control Applications', 'pins':[
            Pin(num='1',name='BOOTSTRAP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='OUTPUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='BOOTSTRAP2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='OUTPUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='DIRECTION',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BRAKE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='CURRENT_SENSE_OUTPUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='~{THERMAL_FLAG_OUTPUT}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX22201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX22201'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Maxim_TDFN-12-1EP_3x3mm_P0.5mm_EP1.7x2.5mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Maxim_TDFN-12-1EP_3x3mm_P0.5mm_EP1.7x2.5mm_ThermalVias', 'keywords':'Brushed Motor Driver', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/max22201-max22207.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nMAX22201\n\nBrushed Motor Driver', 'pins':[
            Pin(num='1',name='ILIM',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{M}',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='ROFF',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ISEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='V_{18}',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OUT2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX22202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX22202'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Maxim_TDFN-12-1EP_3x3mm_P0.5mm_EP1.7x2.5mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Maxim_TDFN-12-1EP_3x3mm_P0.5mm_EP1.7x2.5mm_ThermalVias', 'keywords':'Brushed Motor Driver', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/max22201-max22207.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nMAX22202\n\nBrushed Motor Driver', 'pins':[
            Pin(num='1',name='ILIM',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{M}',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PHASE',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='ENBL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ISEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='V_{18}',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OUT2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX22207', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX22207'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Maxim_TDFN-12-1EP_3x3mm_P0.5mm_EP1.7x2.5mm_ThermalVias'], 'footprint':'Package_DFN_QFN:Maxim_TDFN-12-1EP_3x3mm_P0.5mm_EP1.7x2.5mm_ThermalVias', 'keywords':'Brushed Motor Driver', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/max22201-max22207.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nMAX22207\n\nBrushed Motor Driver', 'pins':[
            Pin(num='1',name='ILIM',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='V_{M}',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='~{FAULT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~{CDROUT}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='GNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='ISEN',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='V_{18}',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OUT2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PAC5527QM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAC5527QM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Qorvo_TQFN66-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm'], 'footprint':'Package_DFN_QFN:Qorvo_TQFN66-48-1EP_6x6mm_P0.4mm_EP4.2x4.2mm', 'keywords':'mcu motor driver', 'description':'', 'datasheet':'https://www.qorvo.com/products/d/da006847', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nPAC5527QM\n\nmcu motor driver', 'pins':[
            Pin(num='1',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='AIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='AIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='AIO6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='AIO7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='AIO8',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='AIO9',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSYS',func=pin_types.PWROUT,unit=1),
            Pin(num='17',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='SW1',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='SW2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='VP',func=pin_types.PWROUT,unit=1),
            Pin(num='21',name='CPL',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='CPH',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='DRL0',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='DRL1',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='DRL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='DRS0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DRH0',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DRS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='DRH1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='DRS2',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='DRH2',func=pin_types.OUTPUT,unit=1),
            Pin(num='32',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VCC33',func=pin_types.PWROUT,unit=1),
            Pin(num='40',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VCC18',func=pin_types.PWROUT,unit=1),
            Pin(num='42',name='VCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='43',name='VCCIO',func=pin_types.PWROUT,unit=1),
            Pin(num='44',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='AIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='AIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='AIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='AIO3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PG001M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PG001M'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Support IC for SLA7042M/SLA7044M', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Sanken/Datasheets/PG001M-Datasheet.ashx', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nPG001M\n\nSupport IC for SLA7042M/SLA7044M', 'pins':[
            Pin(num='1',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='DATA_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='DATA_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='~{STROBE}',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CLK_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VECTOR',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CLK_IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{CW}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='MSEL_1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='MSEL_2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{MONITOR}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Pololu_Breakout_A4988', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Pololu_Breakout_A4988'}), 'ref_prefix':'A', 'fplist':['Module:Pololu_Breakout-16_15.2x20.3mm'], 'footprint':'Module:Pololu_Breakout-16_15.2x20.3mm', 'keywords':'Pololu Breakout Board Stepper Driver A4988', 'description':'', 'datasheet':'https://www.pololu.com/product/2980/pictures', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nPololu_Breakout_A4988\n\nPololu Breakout Board Stepper Driver A4988', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='MS1',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='MS2',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='MS3',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='1B',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='1A',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='2A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='2B',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VMOT',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{ENABLE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Pololu_Breakout_DRV8825', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Pololu_Breakout_DRV8825'}), 'ref_prefix':'A', 'fplist':['Module:Pololu_Breakout-16_15.2x20.3mm'], 'footprint':'Module:Pololu_Breakout-16_15.2x20.3mm', 'keywords':'Pololu Breakout Board Stepper Driver DRV8825', 'description':'', 'datasheet':'https://www.pololu.com/product/2982', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nPololu_Breakout_DRV8825\n\nPololu Breakout Board Stepper Driver DRV8825', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='M0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='~{SLP}',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{FLT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='B1',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='B2',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VMOT',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{EN}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SLA7044M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SLA7044M'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.sumzi.com/upload/files/2007/07/2007073114282034189.PDF', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSLA7044M\n\nStepper driver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{STROBE}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{CLOCK}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{OUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='RS',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RS',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='OUT',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='~{STROBE}',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='REF',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='Vdd',func=pin_types.PWRIN,unit=2),
            Pin(num='16',name='~{CLOCK}',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='DATA',func=pin_types.INPUT,unit=2),
            Pin(num='18',name='~{OUT}',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '5', '8', '6', '7', '2', '1', '9', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '15', '10', '13', '11', '17', '18', '16', '12']}] }),
        Part(**{ 'name':'SLA7070MPRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SLA7070MPRT'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.semicon.sanken-ele.co.jp/sk_content/sla7070mprt_ds_en.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSLA7070MPRT\n\nStepper driver', 'pins':[
            Pin(num='1',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='REF/SLEEP1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CW/CCW',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='FLAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SENSE_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SENSE_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='M3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SLA7075MPRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SLA7075MPRT'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.semicon.sanken-ele.co.jp/sk_content/sla7075mprt_ds_en.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSLA7075MPRT\n\nStepper driver', 'pins':[
            Pin(num='1',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='REF/SLEEP1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CW/CCW',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='FLAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SENSE_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SENSE_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='MO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='M3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN754410NE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN754410NE'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_DIP:DIP-16_W7.62mm', 'keywords':'h-bridge motor driver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn754410.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSN754410NE\n\nh-bridge motor driver', 'pins':[
            Pin(num='1',name='1,2EN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3A',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='3Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='4Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='4A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='1Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='2Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='3,4EN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STK672-040-E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STK672-040-E'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/EN5227-D.PDF', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSTK672-040-E\n\nStepper driver', 'pins':[
            Pin(num='1',name='~{B}',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='M3',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='M4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='M5',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='CWB',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='RETURN',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='MOI',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='MO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='MO2',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='SG',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PG',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PG',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{A}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Vref',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='M1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STK672-080-E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STK672-080-E'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/EN6507-D.PDF', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSTK672-080-E\n\nStepper driver', 'pins':[
            Pin(num='1',name='PG',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='CWB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='M3',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='MOI',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='ENABLE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='BB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='B',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='AB',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Vref',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='M2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STSPIN220', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STSPIN220'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm'], 'footprint':'Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm', 'keywords':'motor driver stepper', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/stspin220.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSTSPIN220\n\nmotor driver stepper', 'pins':[
            Pin(num='1',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUTB1',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TOFF',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='EN/FLT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='STBY/RESET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MODE2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='MODE1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='STCK',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='OUTA1',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='SENSEA',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='OUTA2',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OUTB2',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='SENSEB',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STSPIN230', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STSPIN230'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm'], 'footprint':'Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm', 'keywords':'motor driver half-bridge', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/stspin230.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSTSPIN230\n\nmotor driver half-bridge', 'pins':[
            Pin(num='1',name='INUL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUTW',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='INWL',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='INWH',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='EN/FLT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='STBY',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='INVL',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='INVH',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='INUH',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='OUTU',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='SENSEU',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OUTV',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='SENSEVW',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STSPIN233', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STSPIN233'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm'], 'footprint':'Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm', 'keywords':'motor driver half-bridge', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/stspin233.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSTSPIN233\n\nmotor driver half-bridge', 'pins':[
            Pin(num='1',name='INU',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUTW',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='INW',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='ENW',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='EN/FAULT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='STBY/RESET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='INV',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='ENV',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='ENU',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='OUTU',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='SENSEU',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='OUTV',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='SENSEV',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SENSEW',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STSPIN240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STSPIN240'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm'], 'footprint':'Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm', 'keywords':'motor driver dc brushed', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/stspin240.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSTSPIN240\n\nmotor driver dc brushed', 'pins':[
            Pin(num='1',name='PHA',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OUTB1',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='TOFF',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='EN/FLT',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='STBY/RESET',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PHB',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='PWMB',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='EPAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PWMA',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='OUTA1',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='SENSEA',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='OUTA2',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OUTB2',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='SENSEB',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TB6612FNG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TB6612FNG'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-24_5.3x8.2mm_P0.65mm'], 'footprint':'Package_SO:SSOP-24_5.3x8.2mm_P0.65mm', 'keywords':'H-bridge motor driver', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/us/product/linear/motordriver/detail.TB6612FNG.html', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTB6612FNG\n\nH-bridge motor driver', 'pins':[
            Pin(num='1',name='AO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='PGND2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='BO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='BO1',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='VM2',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VM3',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='PWMB',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='BIN2',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='BIN1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='STBY',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='AO1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AIN1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='AIN2',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='PWMA',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='VM1',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='PGND1',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='PGND1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='AO2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='AO2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='BO2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='BO2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='PGND2',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TC78H670FTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TC78H670FTG'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm'], 'footprint':'Package_DFN_QFN:VQFN-16-1EP_3x3mm_P0.5mm_EP1.8x1.8mm', 'keywords':'stepping motor driver', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/TC78H670FTG_datasheet_en_20210209.pdf?did=68606&prodName=TC78H670FTG', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTC78H670FTG\n\nstepping motor driver', 'pins':[
            Pin(num='2',name='AGND',func=pin_types.PWRIN),
            Pin(num='3',name='VM',func=pin_types.PWRIN),
            Pin(num='4',name='PGND_A',func=pin_types.PWRIN),
            Pin(num='5',name='OUT_A+',func=pin_types.OUTPUT),
            Pin(num='6',name='OUT_A-',func=pin_types.OUTPUT),
            Pin(num='7',name='OUT_B-',func=pin_types.OUTPUT),
            Pin(num='8',name='OUT_B+',func=pin_types.OUTPUT),
            Pin(num='1',name='MODE3',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OSCM',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~{STBY}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='EN/~{ERR}',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='MODE0',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='MODE1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='MODE2',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND_PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='PGND_B',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC2041-LA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC2041-LA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.3x5.3mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-48-1EP_7x7mm_P0.5mm_EP5.3x5.3mm_ThermalVias', 'keywords':'Dual driver stepper motor', 'description':'', 'datasheet':'https://www.trinamic.com/fileadmin/assets/Products/ICs_Documents/TMC2041_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC2041-LA\n\nDual driver stepper motor', 'pins':[
            Pin(num='1',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='SWION',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SWSEL',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='O2A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='BR2A',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='O2A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='GNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='O2B1',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='BR2B',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='O2B2',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='NEXTADDR',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='DIR2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='STEP2',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='DIR1',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='STEP1',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='~{DRV_ENN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CSN/IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='VSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='33',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='CPO',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='CPI',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='O1B2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SCK/IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='BR1B',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='O1B1',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='GNDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='O1A2',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='BR1A',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='O1A1',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='TST_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='SDI/IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='GNDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SDO',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='SWIOP',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC2100-LA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC2100-LA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_5x6mm_P0.5mm_EP3.6x4.1mm_ThermalVias'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_5x6mm_P0.5mm_EP3.6x4.1mm_ThermalVias', 'keywords':'Driver stepper motor', 'description':'', 'datasheet':'https://www.trinamic.com/fileadmin/assets/Products/ICs_Documents/TMC2100_datasheet_Rev1.08.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC2100-LA\n\nDriver stepper motor', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GNDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='BRB',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='OB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='CFG4',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='CFG5',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='CFG3',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='ERROR',func=pin_types.OPENCOLL,unit=1),
            Pin(num='21',name='INDEX',func=pin_types.OPENCOLL,unit=1),
            Pin(num='22',name='~{CFG6_ENN}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AIN_REF',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='CP0',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='CPI',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CFG2',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='BRA',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='OA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='GNDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='TST_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CFG1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='CFG0',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC2100-TA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC2100-TA'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm_ThermalVias'], 'footprint':'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm_ThermalVias', 'keywords':'Standalone driver stepper motor', 'description':'', 'datasheet':'https://www.trinamic.com/fileadmin/assets/Products/ICs_Documents/TMC2100_datasheet_Rev1.08.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC2100-TA\n\nStandalone driver stepper motor', 'pins':[
            Pin(num='1',name='TST_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='GNDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GNDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='OB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='BRB',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='OB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='CFG4',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='CFG5',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='ERROR',func=pin_types.OPENCOLL,unit=1),
            Pin(num='27',name='INDEX',func=pin_types.OPENCOLL,unit=1),
            Pin(num='28',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='~{CFG6_ENN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CFG3',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='AIN_REF',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='CP0',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='CPI',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VSA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CFG2',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='OA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='44',name='BRA',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='OA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='GNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CFG1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='CFG0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DIR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC2130-LA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC2130-LA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-36-1EP_5x6mm_P0.5mm_EP3.6x4.1mm'], 'footprint':'Package_DFN_QFN:QFN-36-1EP_5x6mm_P0.5mm_EP3.6x4.1mm', 'keywords':'stepper motor driver', 'description':'', 'datasheet':'http://www.trinamic.com/fileadmin/assets/Products/ICs_Documents/TMC2130_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC2130-LA\n\nstepper motor driver', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SPI_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='BRB',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='OB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='DCO',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='DCEN_CFG4',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='DCIN_CFG5',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{CS}_CFG3',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DIAG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='DIAG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='~{DRV_EN}_CFG6',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='AIN_IREF',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='26',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='CPO',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='CPI',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SCK_CFG2',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='VSA',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='OA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='33',name='BRA',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='OA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='35',name='GNDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='TST_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SDI_CFG1',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='SDO_CFG0',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='DNC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC2130-TA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC2130-TA'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm'], 'footprint':'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm', 'keywords':'stepper motor driver', 'description':'', 'datasheet':'http://www.trinamic.com/fileadmin/assets/Products/ICs_Documents/TMC2130_datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC2130-TA\n\nstepper motor driver', 'pins':[
            Pin(num='1',name='TST_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='SPI_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='OB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='BRB',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='OB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='DCO',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='DCEN_CFG4',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='DCIN_CFG5',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='DIAG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DIAG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='~{DRV_EN}_CFG6',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{CS}_CFG3',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='AIN_IREF',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='CPO',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='CPI',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VSA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SCK_CFG2',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='OA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='44',name='BRA',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='OA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='GNDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SDI_CFG1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='SDO_CFG0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DIR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC2160', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC2160'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm'], 'footprint':'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm', 'keywords':'Standalone driver stepper motor', 'description':'', 'datasheet':'https://www.trinamic.com/fileadmin/assets/Products/ICs_Documents/TMC2160A-datasheet_Rev1.06.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC2160\n\nStandalone driver stepper motor', 'pins':[
            Pin(num='1',name='HB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SRBL',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='TST_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{CS}_CFG3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SCK_CFG2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDI_CFG1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SDO_CFG0',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='GNDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='VCC_IO',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='SPI_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='DCEN_CFG4',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='DCIN_CFG5',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='DCO_CFG6',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='DIAG0',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='DIAG1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='~{DRV_EN}',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='12VOUT',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='CPO',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='CPI',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='CA2',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='HA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='BMA2',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='LA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='LA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VSA',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='BMA1',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='HA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='CA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='CB2',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='HB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='BMB2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='LB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='LB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='BMB1',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SRAL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SRAH',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SRBH',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC2202-WA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC2202-WA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-32-1EP_5x5mm_P0.5mm_EP3.4x3.4mm_ThermalVias'], 'footprint':'Package_DFN_QFN:TQFN-32-1EP_5x5mm_P0.5mm_EP3.4x3.4mm_ThermalVias', 'keywords':'Standalone driver stepper motor', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/TMC2202_TMC2208_TMC2224_datasheet_rev1.13.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC2202-WA\n\nStandalone driver stepper motor', 'pins':[
            Pin(num='1',name='OB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='MS1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='MS2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DIAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='PDN_UART',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='OA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='BRA',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='OA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='OB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='BRB',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='ENN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CPO',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='CPI',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VCP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC2208-LA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC2208-LA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-32-1EP_5x5mm_P0.5mm_EP3.4x3.4mm_ThermalVias'], 'footprint':'Package_DFN_QFN:TQFN-32-1EP_5x5mm_P0.5mm_EP3.4x3.4mm_ThermalVias', 'keywords':'Standalone driver stepper motor', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/TMC2202_TMC2208_TMC2224_datasheet_rev1.13.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC2208-LA\n\nStandalone driver stepper motor', 'pins':[
            Pin(num='1',name='OB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='MS2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='DIAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='INDEX',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='PDN_UART',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='ENN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='OA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='BRA',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='OA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='OB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='BRB',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CPO',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CPI',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='MS1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC2224-LA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC2224-LA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-32-1EP_5x5mm_P0.5mm_EP3.4x3.4mm_ThermalVias'], 'footprint':'Package_DFN_QFN:TQFN-32-1EP_5x5mm_P0.5mm_EP3.4x3.4mm_ThermalVias', 'keywords':'Standalone driver stepper motor', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/TMC2202_TMC2208_TMC2224_datasheet_rev1.13.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC2224-LA\n\nStandalone driver stepper motor', 'pins':[
            Pin(num='1',name='MS2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='OA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='BRB',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='TEST',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='INDEX',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='PDN_UART',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='DIAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='SPREAD',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='ENN',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='MS1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='CPO',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CPI',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='BRA',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC2226-SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC2226-SA'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.75x6.2mm_ThermalVias'], 'footprint':'Package_SO:HTSSOP-28-1EP_4.4x9.7mm_P0.65mm_EP2.75x6.2mm_ThermalVias', 'keywords':'Standalone driver stepper motor', 'description':'', 'datasheet':'https://www.trinamic.com/fileadmin/assets/Products/ICs_Documents/TMC2226_datasheet_rev1.10.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC2226-SA\n\nStandalone driver stepper motor', 'pins':[
            Pin(num='1',name='OB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SPREAD',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='12',name='MS1_AD0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='MS2_AD1',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='DIAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='INDEX',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='PDN_UART',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='BRB',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='STDBY',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='OA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='BRA',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='OA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='CPO',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CPI',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC262', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC262'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.45x3.45mm', 'keywords':'trinamic tlc262 stepper', 'description':'', 'datasheet':'https://www.trinamic.com/fileadmin/assets/Products/ICs_Documents/TMC262_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC262\n\ntrinamic tlc262 stepper', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SD0',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CSN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='~{ENN}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SRB',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='LB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='LB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='HA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='BMB1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BMB2',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='HB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='HB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='VHS',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='TST_ANA',func=pin_types.OUTPUT,unit=1),
            Pin(num='27',name='SG_TST',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='GNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='HA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='TST_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='DIE_PAD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BMA2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='BMA1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='LA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='LA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SRA',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='5VOUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC2660', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC2660'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Standalone driver stepper motor', 'description':'', 'datasheet':'https://www.trinamic.com/fileadmin/assets/Products/ICs_Documents/TMC2660_datasheet_Rev1.07.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC2660\n\nStandalone driver stepper motor', 'pins':[
            Pin(num='1',name='n.c.',func=pin_types.FREE,unit=1),
            Pin(num='10',name='OA2',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='OA2',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='SRA',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='SDO',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='SDI',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SCK',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='OA1',func=pin_types.PWROUT,unit=1),
            Pin(num='20',name='n.c.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SRB',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='OB2',func=pin_types.PWROUT,unit=1),
            Pin(num='24',name='OB2',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='BRB',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='OB1',func=pin_types.PWROUT,unit=1),
            Pin(num='27',name='OB1',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='OB2',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='OB2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OA1',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='VSB',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='OB1',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='OB1',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='n.c.',func=pin_types.FREE,unit=1),
            Pin(num='34',name='n.c.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='35',name='VHS',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='ST_ALONE/TST_ANA',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='SG_TST',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VSA',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='DIR',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='STEP',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='TST_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OA2',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='OA2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OA1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OA1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='BRA',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC5130A-TA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC5130A-TA'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm_ThermalVias'], 'footprint':'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm_ThermalVias', 'keywords':'Standalone driver stepper motor', 'description':'', 'datasheet':'https://www.trinamic.com/fileadmin/assets/Products/ICs_Documents/TMC5130_datasheet_Rev1.17.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC5130A-TA\n\nStandalone driver stepper motor', 'pins':[
            Pin(num='1',name='TST_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='SD_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='SPI_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='OB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='BRB',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='OB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='ENCN_DCO',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='ENCB_DCEN_CFG4',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='ENCA_DCIN_CFG5',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='SWN_DIAG0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SWP_DIAG1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SWSEL',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='~{DRV_EN}_CFG6',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{CS}_CFG3',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='AIN_IREF',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='CP0',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='CPI',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='VSA',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='SCK_CFG2',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='41',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='42',name='OA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='44',name='BRA',func=pin_types.PASSIVE,unit=1),
            Pin(num='45',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='OA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='GNDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SDI_NAI_CFG1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='SDO_NAO_CFG0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='REFL_STEP',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='REFR_DIR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMC5160A-TA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMC5160A-TA'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm_ThermalVias'], 'footprint':'Package_QFP:TQFP-48-1EP_7x7mm_P0.5mm_EP5x5mm_ThermalVias', 'keywords':'stepper motor driver trinamic', 'description':'', 'datasheet':'https://www.trinamic.com/fileadmin/assets/Products/ICs_Documents/TMC5160A_Datasheet_Rev1.14.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nTMC5160A-TA\n\nstepper motor driver trinamic', 'pins':[
            Pin(num='1',name='HB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='SRBL',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='TST_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~{CS}/CFG3',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SCK/CFG2',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDI/CFG1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SDO/CFG0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='REFL/STEP',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='REFR/DIR',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='GNDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CB1',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='SD_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SPI_MODE',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='ENCB/DCEN/CFG4',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='ENCA/DCIN/CFG5',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='ENCN/DCO/CFG6',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='SWN/DIAG0',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='SWP/DIAG1',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='~{DRV_EN}',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='12VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='30',name='GNDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='CPO',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='CPI',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='VCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='CA2',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='HA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='37',name='BMA2',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='LA2',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='LA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VSA',func=pin_types.PWRIN,unit=1),
            Pin(num='40',name='BMA1',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='HA1',func=pin_types.OUTPUT,unit=1),
            Pin(num='42',name='CA1',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='CB2',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='HB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='BMB2',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='LB2',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='LB1',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='BMB1',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='EP',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='5VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SRAL',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SRAH',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='SRBH',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VNH2SP30', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VNH2SP30'}), 'ref_prefix':'U', 'fplist':['Package_SO:ST_MultiPowerSO-30'], 'footprint':'Package_SO:ST_MultiPowerSO-30', 'keywords':'full-bridge h-bridge', 'description':'', 'datasheet':'http://www.st.com/content/ccc/resource/technical/document/datasheet/group2/66/b8/f5/2c/9a/66/41/c7/CD00043711/files/CD00043711.pdf/jcr:content/translations/en.CD00043711.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nVNH2SP30\n\nfull-bridge h-bridge', 'pins':[
            Pin(num='1',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='EN/DIAB',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='INB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OUTB',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='GNDB',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GNDB',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='GNDB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='OUTB',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='OUTA',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GNDA',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='GNDA',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='OUTA',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='OUTB',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='OUTA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='INA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='EN/DIAA',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='CS',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VNH5019A-E', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VNH5019A-E'}), 'ref_prefix':'U', 'fplist':['Package_SO:ST_MultiPowerSO-30'], 'footprint':'Package_SO:ST_MultiPowerSO-30', 'keywords':'full-bridge h-bridge', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/vnh5019a-e.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nVNH5019A-E\n\nfull-bridge h-bridge', 'pins':[
            Pin(num='1',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='INB',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='CP',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='OUTB',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='GNDB',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GNDB',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='GNDB',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='OUTB',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='OUTA',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='GNDA',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='GNDA',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='OUTA',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='OUTB',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='OUTA',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='INA',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='EN/DIAGA',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='CS_DIS',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='CS',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='EN/DIAGB',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZXBM5210-S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZXBM5210-S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'H-bridge, motor driver, PWM, single coil', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ZXBM5210.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nZXBM5210-S\n\nH-bridge, motor driver, PWM, single coil', 'pins':[
            Pin(num='1',name='OUT1',func=pin_types.OUTPUT),
            Pin(num='2',name='VM',func=pin_types.PWRIN),
            Pin(num='3',name='VDD',func=pin_types.PWRIN),
            Pin(num='4',name='FWD',func=pin_types.INPUT),
            Pin(num='5',name='REV',func=pin_types.INPUT),
            Pin(num='6',name='VREF',func=pin_types.INPUT),
            Pin(num='7',name='OUT2',func=pin_types.OUTPUT),
            Pin(num='8',name='GND',func=pin_types.PWRIN)], 'unit_defs':[] }),
        Part(**{ 'name':'ZXBM5210-SP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZXBM5210-SP'}), 'ref_prefix':'U', 'fplist':['Package_SO:Diodes_SO-8EP'], 'footprint':'Package_SO:Diodes_SO-8EP', 'keywords':'H-bridge, motor driver, PWM, single coil', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/ZXBM5210.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nZXBM5210-SP\n\nH-bridge, motor driver, PWM, single coil', 'pins':[
            Pin(num='1',name='OUT1',func=pin_types.OUTPUT),
            Pin(num='2',name='VM',func=pin_types.PWRIN),
            Pin(num='3',name='VDD',func=pin_types.PWRIN),
            Pin(num='4',name='FWD',func=pin_types.INPUT),
            Pin(num='5',name='REV',func=pin_types.INPUT),
            Pin(num='6',name='VREF',func=pin_types.INPUT),
            Pin(num='7',name='OUT2',func=pin_types.OUTPUT),
            Pin(num='8',name='GND',func=pin_types.PWRIN),
            Pin(num='9',name='GND',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'A4950K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A4950K'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8-1EP_3.9x4.9mm_P1.27mm_EP2.41x3.3mm', 'Package_SO:SOIC-8-1EP_3.9x4.9mm_P1.27mm_EP2.41x3.3mm'], 'footprint':'Package_SO:SOIC-8-1EP_3.9x4.9mm_P1.27mm_EP2.41x3.3mm', 'keywords':'full-bridge h-bridge', 'description':'', 'datasheet':'http://www.allegromicro.com/~/media/Files/Datasheets/A4950-Datasheet.ashx', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nA4950K\n\nfull-bridge h-bridge', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='LSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='PAD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'A4953_LJ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A4953_LJ'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8-1EP_3.9x4.9mm_P1.27mm_EP2.41x3.3mm', 'Package_SO:SOIC-8-1EP_3.9x4.9mm_P1.27mm_EP2.41x3.3mm', 'Package_SO:SOIC-8-1EP_3.9x4.9mm_P1.27mm_EP2.41x3.3mm'], 'footprint':'Package_SO:SOIC-8-1EP_3.9x4.9mm_P1.27mm_EP2.41x3.3mm', 'keywords':'Full-bridge h-bridge', 'description':'', 'datasheet':'www.allegromicro.com/~/media/Files/Datasheets/A4952-3-Datasheet.ashx?la=en', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nA4953_LJ\n\nFull-bridge h-bridge', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUT1',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='LSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OUT2',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='PAD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8212P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8212P'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-8-1EP_2x2mm_P0.5mm_EP0.9x1.6mm', 'Package_SON:WSON-8-1EP_2x2mm_P0.5mm_EP0.9x1.6mm_ThermalVias'], 'footprint':'Package_SON:WSON-8-1EP_2x2mm_P0.5mm_EP0.9x1.6mm', 'keywords':'half bridge driver', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/drv8212p.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8212P\n\nhalf bridge driver', 'pins':[
            Pin(num='1',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DRV8837', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DRV8837'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-8-1EP_2x2mm_P0.5mm_EP0.9x1.6mm', 'Package_SON:WSON-8-1EP_2x2mm_P0.5mm_EP0.9x1.6mm_ThermalVias', 'Package_SON:WSON-8-1EP_2x2mm_P0.5mm_EP0.9x1.6mm'], 'footprint':'Package_SON:WSON-8-1EP_2x2mm_P0.5mm_EP0.9x1.6mm', 'keywords':'half bridge driver', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/drv8837.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nDRV8837\n\nhalf bridge driver', 'pins':[
            Pin(num='1',name='VM',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{SLEEP}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L293D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L293D'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-16_W7.62mm', 'Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_DIP:DIP-16_W7.62mm', 'keywords':'Half-H Driver Motor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/l293.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nL293D\n\nHalf-H Driver Motor', 'pins':[
            Pin(num='1',name='EN1,2',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='3A',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='3Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='4Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='4A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='VCC1',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='1Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='2Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC2',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='EN3,4',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L298N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L298N'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead5.84mm_TabDown', 'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead5.84mm_TabDown', 'keywords':'H-bridge motor driver', 'description':'', 'datasheet':'http://www.st.com/st-web-ui/static/active/en/resource/technical/document/datasheet/CD00000240.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nL298N\n\nH-bridge motor driver', 'pins':[
            Pin(num='1',name='SENSE_A',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='EnB',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='OUT3',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='OUT4',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='SENSE_B',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='EnA',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='Vss',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SLA7042M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SLA7042M'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'www.sumzi.com/upload/files/2007/07/2007073114282034189.PDF', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSLA7042M\n\nStepper driver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~{STROBE}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Vdd',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{CLOCK}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DATA',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{OUT}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='RS',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='RS',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='OUT',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='~{STROBE}',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='REF',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='Vdd',func=pin_types.PWRIN,unit=2),
            Pin(num='16',name='~{CLOCK}',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='DATA',func=pin_types.INPUT,unit=2),
            Pin(num='18',name='~{OUT}',func=pin_types.OUTPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '6', '1', '5', '3', '9', '7', '8', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['18', '12', '16', '14', '15', '13', '17', '11', '10']}] }),
        Part(**{ 'name':'SLA7071MPRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SLA7071MPRT'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.semicon.sanken-ele.co.jp/sk_content/sla7071mprt_ds_en.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSLA7071MPRT\n\nStepper driver', 'pins':[
            Pin(num='1',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='REF/SLEEP1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CW/CCW',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='FLAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SENSE_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SENSE_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='M3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SLA7072MPRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SLA7072MPRT'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.semicon.sanken-ele.co.jp/sk_content/sla7072mprt_ds_en.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSLA7072MPRT\n\nStepper driver', 'pins':[
            Pin(num='1',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='REF/SLEEP1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CW/CCW',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='FLAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SENSE_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SENSE_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='M3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SLA7073MPRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SLA7073MPRT'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.semicon.sanken-ele.co.jp/sk_content/sla7073mprt_ds_en.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSLA7073MPRT\n\nStepper driver', 'pins':[
            Pin(num='1',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='REF/SLEEP1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CW/CCW',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='FLAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SENSE_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SENSE_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='N.C.',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='M3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SLA7076MPRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SLA7076MPRT'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.semicon.sanken-ele.co.jp/sk_content/sla7076mprt_ds_en.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSLA7076MPRT\n\nStepper driver', 'pins':[
            Pin(num='1',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='REF/SLEEP1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CW/CCW',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='FLAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SENSE_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SENSE_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='MO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='M3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SLA7077MPRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SLA7077MPRT'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.semicon.sanken-ele.co.jp/sk_content/sla7077mprt_ds_en.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSLA7077MPRT\n\nStepper driver', 'pins':[
            Pin(num='1',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='REF/SLEEP1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CW/CCW',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='FLAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SENSE_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SENSE_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='MO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='M3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SLA7078MPRT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SLA7078MPRT'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Stepper driver', 'description':'', 'datasheet':'http://www.semicon.sanken-ele.co.jp/sk_content/sla7078mprt_ds_en.pdf', 'search_text':'/usr/share/kicad/symbols/Driver_Motor.kicad_sym\nSLA7078MPRT\n\nStepper driver', 'pins':[
            Pin(num='1',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VBB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='REF/SLEEP1',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='RESET',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='CW/CCW',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='FLAG',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='SENSE_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='~{OUTB}',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='OUTB',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='~{OUTA}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='SENSE_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='MO',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='M1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='M2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='M3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])